==> chromium-browser_34.0.1847.116.orig.tar.xz: chromium-34.0.1847.116/chrome/browser/extensions/api/webrtc_logging_private/webrtc_logging_private_api_stub.cc <==
// Copyright 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
//
// Stub implementation used when WebRTC is not enabled.

#include "chrome/browser/extensions/api/webrtc_logging_private/webrtc_logging_private_api.h"

namespace extensions {

namespace {

const char kErrorNotSupported[] = "Not supported";

}  // namespace

WebrtcLoggingPrivateSetMetaDataFunction::
WebrtcLoggingPrivateSetMetaDataFunction() {}

WebrtcLoggingPrivateSetMetaDataFunction::
~WebrtcLoggingPrivateSetMetaDataFunction() {}

bool WebrtcLoggingPrivateSetMetaDataFunction::RunImpl() {
  SetError(kErrorNotSupported);
  SendResponse(false);
  return false;
}

void WebrtcLoggingPrivateSetMetaDataFunction::SetMetaDataCallback(
    bool success, const std::string& error_message) {}

WebrtcLoggingPrivateStartFunction::WebrtcLoggingPrivateStartFunction() {}

WebrtcLoggingPrivateStartFunction::~WebrtcLoggingPrivateStartFunction() {}

bool WebrtcLoggingPrivateStartFunction::RunImpl() {
  SetError(kErrorNotSupported);
  SendResponse(false);
  return false;
}

void WebrtcLoggingPrivateStartFunction::StartCallback(
    bool success, const std::string& error_message) {}

WebrtcLoggingPrivateSetUploadOnRenderCloseFunction::
WebrtcLoggingPrivateSetUploadOnRenderCloseFunction() {}

WebrtcLoggingPrivateSetUploadOnRenderCloseFunction::
~WebrtcLoggingPrivateSetUploadOnRenderCloseFunction() {}

bool WebrtcLoggingPrivateSetUploadOnRenderCloseFunction::RunImpl() {
  SetError(kErrorNotSupported);
  SendResponse(false);
  return false;
}

WebrtcLoggingPrivateStopFunction::WebrtcLoggingPrivateStopFunction() {}

WebrtcLoggingPrivateStopFunction::~WebrtcLoggingPrivateStopFunction() {}

bool WebrtcLoggingPrivateStopFunction::RunImpl() {
  SetError(kErrorNotSupported);
  SendResponse(false);
  return false;
}

void WebrtcLoggingPrivateStopFunction::StopCallback(
    bool success, const std::string& error_message) {}

WebrtcLoggingPrivateUploadFunction::WebrtcLoggingPrivateUploadFunction() {}

WebrtcLoggingPrivateUploadFunction::~WebrtcLoggingPrivateUploadFunction() {}

bool WebrtcLoggingPrivateUploadFunction::RunImpl() {
  SetError(kErrorNotSupported);
  SendResponse(false);
  return false;
}

void WebrtcLoggingPrivateUploadFunction::UploadCallback(
    bool success, const std::string& report_id,
    const std::string& error_message) {
}

WebrtcLoggingPrivateDiscardFunction::WebrtcLoggingPrivateDiscardFunction() {}

WebrtcLoggingPrivateDiscardFunction::~WebrtcLoggingPrivateDiscardFunction() {}

bool WebrtcLoggingPrivateDiscardFunction::RunImpl() {
  SetError(kErrorNotSupported);
  SendResponse(false);
  return false;
}

void WebrtcLoggingPrivateDiscardFunction::DiscardCallback(
    bool success, const std::string& error_message) {}

}  // namespace extensions

==> chromium-browser_49.0.2623.108.orig.tar.xz: chromium-49.0.2623.108/chrome/browser/extensions/api/webrtc_logging_private/webrtc_logging_private_api_stub.cc <==
// Copyright 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
//
// Stub implementation used when WebRTC is not enabled.

#include "chrome/browser/extensions/api/webrtc_logging_private/webrtc_logging_private_api.h"

namespace extensions {

namespace {

const char kErrorNotSupported[] = "Not supported";

}  // namespace

bool WebrtcLoggingPrivateSetMetaDataFunction::RunAsync() {
  SetError(kErrorNotSupported);
  SendResponse(false);
  return false;
}

bool WebrtcLoggingPrivateStartFunction::RunAsync() {
  SetError(kErrorNotSupported);
  SendResponse(false);
  return false;
}

bool WebrtcLoggingPrivateSetUploadOnRenderCloseFunction::RunAsync() {
  SetError(kErrorNotSupported);
  SendResponse(false);
  return false;
}

bool WebrtcLoggingPrivateStopFunction::RunAsync() {
  SetError(kErrorNotSupported);
  SendResponse(false);
  return false;
}

bool WebrtcLoggingPrivateStoreFunction::RunAsync() {
  SetError(kErrorNotSupported);
  SendResponse(false);
  return false;
}

bool WebrtcLoggingPrivateUploadStoredFunction::RunAsync() {
  SetError(kErrorNotSupported);
  SendResponse(false);
  return false;
}

bool WebrtcLoggingPrivateUploadFunction::RunAsync() {
  SetError(kErrorNotSupported);
  SendResponse(false);
  return false;
}

bool WebrtcLoggingPrivateDiscardFunction::RunAsync() {
  SetError(kErrorNotSupported);
  SendResponse(false);
  return false;
}

bool WebrtcLoggingPrivateStartRtpDumpFunction::RunAsync() {
  SetError(kErrorNotSupported);
  SendResponse(false);
  return false;
}

bool WebrtcLoggingPrivateStopRtpDumpFunction::RunAsync() {
  SetError(kErrorNotSupported);
  SendResponse(false);
  return false;
}

bool WebrtcLoggingPrivateStartAudioDebugRecordingsFunction::RunAsync() {
  SetError(kErrorNotSupported);
  SendResponse(false);
  return false;
}

bool WebrtcLoggingPrivateStopAudioDebugRecordingsFunction::RunAsync() {
  SetError(kErrorNotSupported);
  SendResponse(false);
  return false;
}

}  // namespace extensions
